/*
 * Log recent interesting occurrences on that chatserver.
 *
 * Part of Chatserv, by Jonathan Lennox.  Written for no particularly good
 * reason, because I felt like it.  Allows multiple people to chat over the
 * net in a relatively straightforward environment.  Disclaimer: I figured out
 * how to do TCP/IP programming by reading man pages.
 *
 * Copyright 1995 Jonathan Lennox
 * Copyright 2017 Russ Allbery <eagle@eyrie.org>
 *
 * See LICENSE for licensing terms.
 */

#include <config.h>
#include <portable/system.h>

#include <errno.h>

#include <util/macros.h>

#include "channels.h"
#include "connections.h"
#include "lastlog.h"

#define LOG_SIZE 100

static char *lastlog[LOG_SIZE];
static int first_entry = 0;
static int last_entry = 0;
static int log_empty = 1;

/* Insert an entry into the log.  -errno on error. */
int insert_to_log(char *entry)
{
  if (((first_entry - last_entry + LOG_SIZE) % LOG_SIZE) == 1) {
    /* The log is full.  The +LOG_SIZE term is to force the operand to
       be positive. */
    free(lastlog[first_entry]);
    first_entry++; first_entry %= LOG_SIZE;
  }

  if (!log_empty) {
    last_entry++; last_entry %= LOG_SIZE;
  }
  lastlog[last_entry] = strdup(entry);
  if (lastlog[last_entry] == NULL)
    return -ENOMEM;
  log_empty = 0;

  return 0;
}


/* commands */
int lastlog_cmd(const char *cmd_name UNUSED, struct connection *user,
                char *args)
{
  int requested, cur_pos, written, retval;

  if (strcmp(args, "") == 0) {
    requested = 10; /* default count.  XXX: settible in conf file? */
  }
  else {
    requested = atoi(args);
  }

  if (log_empty || requested <= 0) return 0;

  if (requested > (last_entry - first_entry + LOG_SIZE) % LOG_SIZE + 1)
    requested = (last_entry - first_entry + LOG_SIZE) % LOG_SIZE + 1;
  /* The number of entries currently in the logfile.  The + 1 is
     because last_entry == first_entry implies we have one entry in
     the log, and analogously for all other cases; it is outside the %
     because we want these in the range 1 .. LOG_SIZE not
     0 .. LOGSIZE - 1.
     */

  written = 0;
  cur_pos = (last_entry - requested + LOG_SIZE + 1) % LOG_SIZE;
  /* Note that if the above condition was met cur_pos now equals
     first_entry. */
  do {
    retval = write_to_user(lastlog[cur_pos], user);
    if (retval) return retval;
    cur_pos++; cur_pos %= LOG_SIZE;
    written++;
  } while ( written < requested );

  return 0;
}
