/*
 * Numeric codes for messages.
 *
 * Part of Chatserv, by Jonathan Lennox.  Written for no particularly good
 * reason, because I felt like it.  Allows multiple people to chat over the
 * net in a relatively straightforward environment.  Disclaimer: I figured out
 * how to do TCP/IP programming by reading man pages.
 *
 * Copyright 1999 Matthew Gerber
 * Copyright 2017 Russ Allbery <eagle@eyrie.org>
 *
 * See LICENSE for licensing terms.
 */

#include <config.h>
#include <portable/system.h>

#include "numerics.h"

/* Return the numeric for a formatting identifier. Since we only do this
   once for each one of these, and it's a small list, there's no real
   reason not to just do it the straightforward way. */
int numeric_for(const char *s)
{
  int l = strlen(s);

  if(!strcmp("send_on_channel_same_channel", s)) return (1001);
  if(!strcmp("pose_on_channel_same_channel", s)) return (1002);
  if(!strcmp("ppose_on_channel_same_channel", s)) return (1003);
  if(!strcmp("roll_on_channel_same_channel", s)) return (1004);
  if(!strcmp("narrate_on_channel_same_channel", s)) return(1005);
  if(!strcmp("send_on_channel_same_channel_alias", s)) return (1006);
  if(!strcmp("pose_on_channel_same_channel_alias", s)) return (1007);
  if(!strcmp("ppose_on_channel_same_channel_alias", s)) return (1008);

  if(!strcmp("send_off_channel_same_channel", s)) return (1011);
  if(!strcmp("pose_off_channel_same_channel", s)) return (1012);
  if(!strcmp("ppose_off_channel_same_channel", s)) return (1013);
  if(!strcmp("roll_off_channel_same_channel", s)) return (1014);
  if(!strcmp("narrate_off_channel_same_channel", s)) return(1015);

  if(!strcmp("send_on_channel_other_channel", s)) return (1021);
  if(!strcmp("pose_on_channel_other_channel", s)) return (1022);
  if(!strcmp("ppose_on_channel_other_channel", s)) return (1023);
  if(!strcmp("roll_on_channel_other_channel", s)) return (1024);
  if(!strcmp("narrate_on_channel_other_channel", s)) return(1025);
  if(!strcmp("send_on_channel_other_channel_alias", s)) return (1026);
  if(!strcmp("pose_on_channel_other_channel_alias", s)) return (1027);
  if(!strcmp("ppose_on_channel_other_channel_alias", s)) return (1028);

  if(!strcmp("send_off_channel_other_channel", s)) return (1031);
  if(!strcmp("pose_off_channel_other_channel", s)) return (1032);
  if(!strcmp("ppose_off_channel_other_channel", s)) return (1033);
  if(!strcmp("roll_off_channel_other_channel", s)) return (1034);
  if(!strcmp("narrate_off_channel_other_channel", s)) return(1035);

  if(!strcmp("send_whisper_sender", s)) return (1101);
  if(!strcmp("pose_whisper_sender", s)) return (1102);
  if(!strcmp("ppose_whisper_sender", s)) return (1103);
  if(!strcmp("roll_whisper_sender", s)) return (1104);
  if(!strcmp("narrate_whisper_sender", s)) return (1105);

  if(!strcmp("send_whisper_recipient", s)) return (1111);
  if(!strcmp("pose_whisper_recipient", s)) return (1112);
  if(!strcmp("ppose_whisper_recipient", s)) return (1113);
  if(!strcmp("roll_whisper_recipient", s)) return (1114);
  if(!strcmp("narrate_whisper_recipient", s)) return (1115);

  if(!strcmp("send_yell", s)) return (1201);
  if(!strcmp("pose_yell", s)) return (1202);
  if(!strcmp("ppose_yell", s)) return (1203);
  if(!strcmp("roll_yell", s)) return (1204);
  if(!strcmp("narrate_yell", s)) return (1205);

  if(!strcmp("signon", s)) return (2001);
  if(!strcmp("signoff", s)) return (2002);
  if(!strcmp("leave_channel", s)) return (2003);
  if(!strcmp("join_channel", s)) return (2004);

  if(!strcmp("channel_topic", s)) return (2101);
  if(!strcmp("channel_topic_changed", s)) return (2102);

  if(!strcmp("current_channels", s)) return (3001);
  if(!strcmp("no_current_channels", s)) return (3002);
  if(!strcmp("primary_channel", s)) return (3003);
  if(!strcmp("no_primary_channel", s)) return (3004);
  if(!strcmp("new_primary_channel", s)) return (3005);
  if(!strcmp("new_no_primary_channel", s)) return (3006);

  if(!strcmp("client_now", s)) return (3101);
  if(!strcmp("client_current", s)) return (3102);

  if(!strcmp("current_nick", s)) return (3201);
  if(!strcmp("nick_no_change", s)) return (3202);
  if(!strcmp("first_nick", s)) return (3203);
  if(!strcmp("nick_changed", s)) return (3204);

  if(!strcmp("current_privs", s)) return (3301);
  if(!strcmp("new_priv_level", s)) return (3302);

  if(!strcmp("current_wrap", s)) return (3401);
  if(!strcmp("no_wrap", s)) return (3402);
  if(!strcmp("new_wrap", s)) return (3403);
  if(!strcmp("new_no_wrap", s)) return (3404);

  if(!strcmp("unorthodox_on", s)) return (3501);
  if(!strcmp("unorthodox_off", s)) return (3502);

  if(!strcmp("now_visible", s)) return (3601);
  if(!strcmp("already_hidden", s)) return (3602);
  if(!strcmp("now_hidden", s)) return (3603);
  if(!strcmp("already_cloaked", s)) return (3604);
  if(!strcmp("now_cloaked", s)) return (3605);

  if(!strcmp("channel_list_header", s)) return (4001);
  if(!strcmp("channel_list_entry", s)) return (4002);

  if(!strcmp("list_header", s)) return (4101);
  if(!strcmp("listall_header", s)) return (4102);
  if(!strcmp("list_format", s)) return (4103);

  if(!strcmp("users_format", s)) return (4201);

  if(!strcmp("whois_origin_dns", s)) return (4301);
  if(!strcmp("whois_origin_no_dns", s)) return (4302);
  if(!strcmp("whois_channels_full", s)) return (4303);
  if(!strcmp("whois_channels_no_primary", s)) return (4304);
  if(!strcmp("whois_channels_none", s)) return (4305);
  if(!strcmp("whois_time", s)) return (4306);

  if(!strcmp("current_time", s)) return (4401);

  if(!strcmp("reload_succeeded", s)) return (5001);

  if(!strcmp("motd", s)) return(6001);
  if(!strcmp("help_text", s)) return(6002);
  if(!strcmp("help_format", s)) return(6003);
  if(!strcmp("_longdesc", s+l-9)) return(6004);

  if(!strcmp("server_start_ll_entry", s)) return(6101);
  if(!strcmp("signon_ll_entry", s)) return(6102);
  if(!strcmp("signoff_ll_entry", s)) return(6103);
  if(!strcmp("nickchange_ll_entry", s)) return(6104);

  if(!strcmp("nick_request", s)) return (8001);

  if(!strcmp("unknown_command", s)) return (9001);
  if(!strcmp("ambiguous_command", s)) return (9002);
  if(!strcmp("failed_executor", s)) return(9005);

  if(!strcmp("unknown_user", s)) return (9101);
  if(!strcmp("bad_recipient", s)) return (9102);
  if(!strcmp("bad_dice_arg", s)) return (9103);
  if(!strcmp("bad_forgery", s)) return (9104);

  if(!strcmp("couldnt_change_topic", s)) return (9201);

  if(!strcmp("invalid_channel", s)) return (9301);
  if(!strcmp("insufficient_privs", s)) return (9303);
  if(!strcmp("invalid_priv_level", s)) return (9304);
  if(!strcmp("invalid_password", s)) return (9305);
  if(!strcmp("nick_in_use", s)) return (9306);
  if(!strcmp("nick_too_long", s)) return (9307);
  if(!strcmp("bad_nick", s)) return (9308);
  if(!strcmp("bad_wrap", s)) return (9309);
  if(!strcmp("bad_client", s)) return (9310);
  if(!strcmp("bad_as", s)) return(9311);

  if(!strcmp("reload_failed", s)) return (9501);

  /* else */
  return(0);
}
